@@ -1,5 +1,7 @@
 from __future__ import annotations
-from typing import List
+from typing import Optional, List
+
+from spotipy2.types import SimplifiedArtist
 
 
 class Track:
@@ -7,7 +9,6 @@ class Track:
         self,
         album,
         artists,
-        available_markets: List[str],
         disc_number: int,
         duration_ms: int,
         explicit: bool,
@@ -22,13 +23,14 @@ class Track:
         track_number: int,
         type: str,
         uri: str,
+        available_markets: Optional[List[str]] = None,
         is_playable: bool = None,
         linked_from: bool = None,
         restrictions: dict = None,
         **kwargs
     ):
         self.album = album
-        self.artists = artists
+        self.artists = [SimplifiedArtist.from_dict(a) for a in artists]
         self.available_markets = available_markets
         self.disc_number = disc_number
         self.duration_ms = duration_ms
@@ -49,5 +51,5 @@ class Track:
         self.restrictions = restrictions
 
     @classmethod
-    async def from_dict(cls, d: dict) -> Track:
+    def from_dict(cls, d: dict) -> Track:
         return cls(**d)
